@@ -1,7 +1,7 @@
 use crate::*;
 
 /// Struct for `cond`
-pub struct Cond<V0: View, V1: View> {
+pub struct Cond<V0, V1> {
     cond: bool,
     if_true: V0,
     if_false: V1,
@@ -65,8 +65,31 @@ where
             self.if_false.commands(id.child(&1), cx, cmds)
         }
     }
+
+    fn gc(&self, id: ViewID, cx: &mut Context, map: &mut StateMap) {
+        if self.cond {
+            self.if_true.gc(id.child(&0), cx, map)
+        } else {
+            self.if_false.gc(id.child(&1), cx, map)
+        }
+    }
+
+    fn access(
+        &self,
+        id: ViewID,
+        cx: &mut Context,
+        nodes: &mut Vec<accesskit::Node>,
+    ) -> Option<accesskit::NodeId> {
+        if self.cond {
+            self.if_true.access(id.child(&0), cx, nodes)
+        } else {
+            self.if_false.access(id.child(&1), cx, nodes)
+        }
+    }
 }
 
+impl<V0, V1> private::Sealed for Cond<V0, V1> {}
+
 /// Switches between views according to a boolean.
 pub fn cond(cond: bool, if_true: impl View, if_false: impl View) -> impl View {
     Cond {
