@@ -1,10 +1,10 @@
 pub use crate::*;
 
-pub struct Focus<V: View, F: Fn(bool) -> V> {
+pub struct Focus<F> {
     func: F,
 }
 
-impl<V, F> View for Focus<V, F>
+impl<V, F> View for Focus<F>
 where
     V: View,
     F: Fn(bool) -> V,
@@ -22,13 +22,13 @@ where
                     cx.focused_id = Some(vid);
                     cx.dirty.lock().unwrap().dirty = true;
                 }
-            },
+            }
             EventKind::Key(KeyPress::Escape, _) => {
                 if cx.focused_id == Some(vid) {
                     cx.focused_id = None;
                     cx.dirty.lock().unwrap().dirty = true;
                 }
-            },
+            }
             _ => (),
         }
         (self.func)(Some(vid) == cx.focused_id).process(event, vid.child(&0), cx, vger)
@@ -55,10 +55,25 @@ where
     fn commands(&self, id: ViewID, cx: &mut Context, cmds: &mut Vec<CommandInfo>) {
         (self.func)(Some(id) == cx.focused_id).commands(id.child(&0), cx, cmds)
     }
+
+    fn gc(&self, id: ViewID, cx: &mut Context, map: &mut StateMap) {
+        (self.func)(Some(id) == cx.focused_id).gc(id.child(&0), cx, map)
+    }
+
+    fn access(
+        &self,
+        id: ViewID,
+        cx: &mut Context,
+        nodes: &mut Vec<accesskit::Node>,
+    ) -> Option<accesskit::NodeId> {
+        (self.func)(Some(id) == cx.focused_id).access(id.child(&0), cx, nodes)
+    }
 }
 
+impl<F> private::Sealed for Focus<F> {}
+
 /// Calls calls a function with true if the view subtree returned
 /// by the function has the keyboard focus.
-pub fn focus<V: View, F: Fn(bool) -> V + 'static>(f: F) -> Focus<V, F> {
+pub fn focus<V: View, F: Fn(bool) -> V + 'static>(f: F) -> impl View {
     Focus { func: f }
 }
