@@ -1,7 +1,7 @@
 use crate::*;
 
 /// Struct for the `geom` modifier.
-pub struct Geom<V: View, F: Fn(LocalSize)> {
+pub struct Geom<V, F> {
     child: V,
     func: F,
 }
@@ -44,8 +44,23 @@ where
     fn commands(&self, id: ViewID, cx: &mut Context, cmds: &mut Vec<CommandInfo>) {
         self.child.commands(id.child(&0), cx, cmds)
     }
+
+    fn gc(&self, id: ViewID, cx: &mut Context, map: &mut StateMap) {
+        self.child.gc(id.child(&0), cx, map)
+    }
+
+    fn access(
+        &self,
+        id: ViewID,
+        cx: &mut Context,
+        nodes: &mut Vec<accesskit::Node>,
+    ) -> Option<accesskit::NodeId> {
+        self.child.access(id.child(&0), cx, nodes)
+    }
 }
 
+impl<V, F> private::Sealed for Geom<V, F> {}
+
 impl<V, F> Geom<V, F>
 where
     V: View + 'static,
